import QtQuick 2.0
import Sailfish.Silica 1.0
import QtFeedback 5.0
import Nemo.Configuration 1.0

Page {
    id: page

    ConfigurationGroup {
        id: vibrateSettings
        path: "/apps/patchmanager/vibrate-on-call"
        property int duration: 100
        property double intensity: 0.5
        property double attackIntensity: 0.5
        property int attackTime: 250
        property int fadeTime: 250
        property double fadeIntensity: 0.0
    }

    SilicaFlickable {
        anchors.fill: parent
        contentHeight: content.height

        VerticalScrollDecorator {
        }

        Column {
            id: content
            width: parent.width
            spacing: Theme.paddingLarge

            PageHeader {
                title: qsTr("Vibrate on call settings")
            }

            HapticsEffect {
                id: activeEffect
                duration: vibrateSettings.duration
                intensity: vibrateSettings.intensity
                attackIntensity: vibrateSettings.attackIntensity
                attackTime: vibrateSettings.attackTime
                fadeTime: vibrateSettings.fadeTime
                fadeIntensity: vibrateSettings.fadeIntensity
            }

            Slider {
                width: parent.width
                label: qsTr("Duration (msecs)")
                maximumValue: 1000
                minimumValue: 25
                stepSize: 1
                value: vibrateSettings.duration
                valueText: value
                onValueChanged: vibrateSettings.duration = value
                onPressAndHold: cancel()
            }

            TextSwitch {
                id: toggle
                text: qsTr("Slow less relevant expert settings")
                checked: false
            }

            Slider {
                width: parent.width
                label: qsTr("Intensity")
                maximumValue: 1
                minimumValue: 0
                stepSize: 0.1
                value: vibrateSettings.intensity
                valueText: value
                onReleased: vibrateSettings.intensity = value
                onPressAndHold: cancel()
                visible: toggle.checked
            }

            Slider {
                width: parent.width
                label: qsTr("Attack Intensity")
                maximumValue: 1
                minimumValue: 0
                stepSize: 0.1
                value: vibrateSettings.attackIntensity
                valueText: value
                onReleased: vibrateSettings.attackIntensity = value
                onPressAndHold: cancel()
                visible: toggle.checked
            }

            Slider {
                width: parent.width
                label: qsTr("Attack Time (msecs)")
                maximumValue: 500
                minimumValue: 0
                stepSize: 1
                value: vibrateSettings.attackTime
                valueText: value
                onValueChanged: vibrateSettings.attackTime = value
                onPressAndHold: cancel()
                visible: toggle.checked
            }

            Slider {
                width: parent.width
                label: qsTr("Fade Time (msecs)")
                maximumValue: 500
                minimumValue: 0
                stepSize: 1
                value: vibrateSettings.fadeTime
                valueText: value
                onValueChanged: vibrateSettings.fadeTime = value
                onPressAndHold: cancel()
                visible: toggle.checked
            }

            Slider {
                width: parent.width
                label: qsTr("Fade Intensity")
                maximumValue: 1
                minimumValue: 0
                stepSize: 0.1
                value: vibrateSettings.fadeIntensity
                valueText: value
                onReleased: vibrateSettings.fadeIntensity = value
                onPressAndHold: cancel()
                visible: toggle.checked
            }

            Button {
                anchors.horizontalCenter: parent.horizontalCenter
                width: (parent.width * .70)
                text: qsTr("Test settings")
                onClicked: {
                    activeEffect.start()
                }
            }
        }
    }
}
